@@ -1,6 +1,6 @@
-from .autoencoder import DAE
+from .autoencoder import DAE, SDAE
 from .categorical import OneHotEncoder, LabelEncoder, TargetEncoder, EmbeddingEncoder, FrequencyEncoder
 from .numerical import Normalizer, QuantileEncoder
 
-__all__ = ['DAE', 'OneHotEncoder', 'LabelEncoder', 'TargetEncoder', 'EmbeddingEncoder',
+__all__ = ['DAE', 'SDAE', 'OneHotEncoder', 'LabelEncoder', 'TargetEncoder', 'EmbeddingEncoder',
            'Normalizer', 'QuantileEncoder', 'FrequencyEncoder']
